.. _deploy-ramdisk:

Building or downloading a deploy ramdisk image
==============================================

Ironic depends on having an image with the ironic-python-agent_ (IPA)
service running on it for controlling and deploying bare metal nodes.

.. TODO(dtantsur): a link to DIB ramdisks once we finally build them

.. _ironic-python-agent: https://docs.openstack.org/ironic-python-agent/train/

Building from source
--------------------

Check the ironic-python-agent-builder_ project for information on how to build
ironic-python-agent ramdisks.

.. _ironic-python-agent-builder: https://docs.openstack.org/ironic-python-agent-builder/latest/
